package com.ruoyi.bst.order.service;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

import com.ruoyi.bst.order.domain.OrderQuery;
import com.ruoyi.bst.order.domain.query.OrderRefundQuery;
import com.ruoyi.bst.order.domain.vo.OrderDailyRefundStatVO;
import com.ruoyi.bst.order.domain.vo.OrderDailyStatVO;
import com.ruoyi.bst.order.domain.vo.OrderRankVO;
import com.ruoyi.bst.order.domain.vo.OrderRefundStatVO;
import com.ruoyi.bst.order.domain.vo.OrderStatVO;

public interface OrderDashboard {

    /**
     * 查询订单统计
     * @param query 查询条件
     * @param keys 查询字段
     * @return 订单统计
     */
    OrderStatVO selectStat(OrderQuery query, List<String> keys);

    /**
     * 查询订单用户数量
     * @param query 查询条件
     * @return 订单用户数量
     */
    Integer selectUserCount(OrderQuery query);

    /**
     * 查询订单数量
     * @param query 查询条件
     * @return 订单数量
     */
    Integer selectCount(OrderQuery query);

    /**
     * 查询订单支付金额
     * @param query 查询条件
     * @return 订单支付金额
     */
    BigDecimal selectPayAmount(OrderQuery query);

    /**
     * 查询待审核的订单数量
     * @param query 查询条件
     * @return 待审核的订单数量
     */
    Integer selectWaitVerifyCount(OrderQuery query);

    /**
     * 查询订单状态数量
     * @param query 查询条件
     * @return 订单状态数量
     */
    Map<String, Integer> selectStatusCount(OrderQuery query);

    /**
     * 查询订单退款金额
     * @param query
     * @param keys
     * @return
     */
    BigDecimal selectRefundAmount(OrderRefundQuery query);

    /**
     * 查询订单退款统计
     * @param query 查询条件
     * @param keys 查询字段
     * @return 订单退款统计
     */
    OrderRefundStatVO selectRefundStat(OrderRefundQuery query, List<String> keys);

    /**
     * 查询订单每日统计
     */
    List<OrderDailyStatVO> selectDailyStat(OrderQuery query, List<String> keys);

    /**
     * 查询订单每日退款统计
     */
    List<OrderDailyRefundStatVO> selectDailyRefundStat(OrderRefundQuery query, List<String> keys);

    /**
     * 查询订单排行榜
     */
    List<OrderRankVO> selectRank(OrderQuery query);
}
